##  LeanIX Terms
  1. Your use of the Application will be governed by the applicable agreement entered into by your company and LeanIX ("LeanIX Terms"). In case of any inconsistency between the LeanIX Terms and these Application Terms, these Application Terms shall take precedence.
  2. You may not use the Application to violate the LeanIX Terms. Any use of the Application that violates the LeanIX Terms will also be a violation of these Application Terms. You will be responsible for any use of the Application that is performed on or through your account.
